@@ -1,11 +1,22 @@
-ts_arithmetic <- function(e1, e2, fun = `-`){
+#' Arithmetic Operators for ts-boxable objects
+#'
+#' Users will call the infix operators
+#'
+#' @param e1 ts-boxable object
+#' @param e2 ts-boxable object
+#' @param fun funcion to apply
+#'
+#' @noRd
+ts_arithmetic <- function(e1, e2, fun = `-`) {
   value <- value2 <- .id <- NULL
   z1 <- copy(ts_dts(e1))
 
-  if (identical(nrow(z1), 0L)) return(e1)
+  if (identical(nrow(z1), 0L)) {
+    return(e1)
+  }
 
   # 'recycling', if a scalar is provided
-  if (length(e2) == 1 && is.numeric(e2)){
+  if (length(e2) == 1L && is.numeric(e2)) {
     z2 <- copy(z1)
     z2[[dts_cname(z2)$value]] <- e2
   } else {
@@ -16,18 +27,15 @@ ts_arithmetic <- function(e1, e2, fun = `-`){
   cname2 <- dts_cname(z2)
   cid <- cname$id
 
-  if (!identical(cname$id, cname2$id)){
-    stop("id columns are not identical", call. = FALSE)
-  }
+  check_identical_ids(cname$id, cname2$id)
 
   setnames(z1, cname$value, "value")
   setnames(z2, cname2$value, "value2")
   setnames(z1, cname$time, "time")
   setnames(z2, cname2$time, "time")
 
-  if (length(cname$id) > 0){
-
-    if (length(cname$id) > 1){
+  if (length(cname$id) > 0) {
+    if (length(cname$id) > 1) {
       sep.str <- "!%!#"
 
       cid <- cname$id
@@ -41,7 +49,6 @@ ts_arithmetic <- function(e1, e2, fun = `-`){
       setnames(z1, ".id", "id")
       setnames(z2, ".id", "id")
       cid <- "id"
-
     }
 
     ll1 <- split(z1, z1[[cid]])[unique(z1[[cid]])]
@@ -53,7 +60,7 @@ ts_arithmetic <- function(e1, e2, fun = `-`){
     z <- rbindlist(Map(merge_time_date, x = ll1, y = ll2), idcol = cid)
 
     # separate id cols
-    if (length(cname$id) > 1){
+    if (length(cname$id) > 1) {
       setnames(z, "id", ".id")
       z <- merge(z, dt.id, by = ".id", sort = FALSE)[, .id := NULL]
       setcolorder(z, c(cname$id, "time", "value", "value2"))
@@ -76,11 +83,11 @@ ts_arithmetic <- function(e1, e2, fun = `-`){
 #' Arithmetic Operators for ts-boxable objects
 #'
 #' @param e1 ts-boxable time series, an object of class `ts`, `xts`, `zoo`,
-#'   `data.frame`, `data.table`, `tbl`, `tbl_ts`, `tbl_time`, `tis`, `irts` or
-#'   `timeSeries`.
+#'   `zooreg`, `data.frame`, `data.table`, `tbl`, `tbl_ts`, `tbl_time`, `tis`,
+#'   `irts` or `timeSeries`.
 #' @param e2 ts-boxable time series, an object of class `ts`, `xts`, `zoo`,
-#'   `data.frame`, `data.table`, `tbl`, `tbl_ts`, `tbl_time`, `tis`, `irts` or
-#'   `timeSeries`.
+#'   `zooreg`, `data.frame`, `data.table`, `tbl`, `tbl_ts`, `tbl_time`, `tis`,
+#'   `irts` or `timeSeries`.
 #' @return a ts-boxable time series, with the same class as the left input.
 #' @examples
 #' head(fdeaths - mdeaths)
@@ -102,5 +109,3 @@ ts_arithmetic <- function(e1, e2, fun = `-`){
 #' @name ts_arithmetic
 #' @export
 `%ts/%` <- function(e1, e2) ts_arithmetic(e1, e2, fun = `/`)
-
-
