@@ -1,13 +1,19 @@
-
-#' @param denominator numeric, set equal to one if percentage change rate is
+#' @param denominator positive number. Set equal to 1 if percentage change rate is
 #'   given a decimal fraction
 #' @name ts_index
 #' @export
+#' @srrstats {G2.4b} *explicit conversion to continuous via `as.numeric()`*
 ts_compound <- function(x, denominator = 100) {
+
   not_in_data <- NULL
   value <- NULL
+
+  denominator <- as.numeric(denominator)
+  stopifnot(denominator > 0)
+  stopifnot(length(denominator) == 1L)
   z <- ts_dts(x)
-  d <- dts_default(z); z <- d$x
+  d <- dts_default(z)
+  z <- d$x
 
   z <- ts_regular(ts_na_omit(z))
 
@@ -27,7 +33,6 @@ ts_compound <- function(x, denominator = 100) {
 }
 
 
-
 #' Indices from Levels or Percentage Rates
 #'
 #' `ts_index` returns an indexed series, with value of 1 at the `base` date or
@@ -35,29 +40,30 @@ ts_compound <- function(x, denominator = 100) {
 #' `ts_compound` builds an index from percentage change rates, starting with 1
 #' and compounding the rates.
 #'
-#' @inherit ts_dts
+#' @inherit ts_default
 #' @param base base date, character string, `Date` or `POSIXct`, at which the
-#'  index is set to 1. If two dates are provided, the average with the range is
+#'  index is set to 1. If two dates are provided, the mean in the range is
 #'  set equal to 1 (see examples).
-#' @return a ts-boxable time series, with the same class as the input.
 #' @examples
-#' head(ts_compound(ts_pc(ts_c(fdeaths, mdeaths))))
-#' head(ts_index(ts_df(ts_c(fdeaths, mdeaths)), "1974-02-01"))
+#' x <- ts_pc(ts_c(fdeaths, mdeaths))
+#' ts_compound(x)
+#' y <- ts_df(ts_c(fdeaths, mdeaths))
+#' ts_index(y, "1974-02-01")
 #' \donttest{
 #' ts_plot(
 #'   `My Expert Knowledge` = ts_chain(
 #'     mdeaths,
-#'     ts_compound(ts_bind(ts_pc(mdeaths), 15, 23, 33))),
+#'     ts_compound(ts_bind(ts_pc(mdeaths), 15, 23, 33))
+#'   ),
 #'   `So Far` = mdeaths,
 #'   title = "A Very Manual Forecast"
 #' )
 #'
-#' # average of 1974 = 1
+#' # mean of 1974 = 1
 #' ts_index(mdeaths, c("1974-01-01", "1974-12-31"))
 #' }
 #' @export
 ts_index <- function(x, base = NULL) {
-
   not_in_data <- NULL
   value <- NULL
   base_value <- NULL
@@ -65,29 +71,33 @@ ts_index <- function(x, base = NULL) {
   . <- NULL
 
   z <- ts_dts(x)
-  d <- dts_default(z); z <- d$x
+  if (nrow(z) == 0L) return(x)
+  d <- dts_default(z)
+  z <- d$x
 
   cid <- dts_cname(z)$id
   .by <- by_expr(cid)
 
-  # use latest non na start point as base candidtate
-  if (is.null(base)){
+  if (all(is.na(d$x$value))) return(x)
+
+  # use latest non na start point as base candidate
+  if (is.null(base)) {
     dt_min_time <- z[
       !is.na(value),
       list(min.time = min(time)),
       by = eval(.by)
     ]
     base <- max(dt_min_time$min.time)
-    z.base <- z[time == base, .(base_value = mean(value)), by = eval(.by)]
+    z.base <- z[is_near(time, base), .(base_value = mean(value)), by = eval(.by)]
 
-  # single date specification
-  } else if(length(base) == 1) {
+    # single date specification
+  } else if (length(base) == 1L) {
     # let ts_span parse base and make sure it exists in data
     base <- range(ts_span(z, start = base)$time)[1]
-    z.base <- z[time == base, .(base_value = mean(value)), by = eval(.by)]
+    z.base <- z[is_near(time, base), .(base_value = mean(value)), by = eval(.by)]
 
-  # range of dates specification (use averages)
-  } else if (length(base) == 2) {
+    # range of dates specification (use averages)
+  } else if (length(base) == 2L) {
     # let ts_span parse base and make sure it exists in data
     base <- range(ts_span(z, start = base[1], end = base[2])$time)
     z.base <- z[
@@ -96,7 +106,7 @@ ts_index <- function(x, base = NULL) {
       by = eval(.by)
     ]
   } else {
-    stop("'base' must be of length 1 or 2, or NULL.")
+    stop0("'base' must be of length 1 or 2, or NULL.")
   }
 
   if (length(cid) > 0) {
