@@ -1,9 +1,3 @@
-library(testthat)
-library(tsbox)
-
-
-context("ts_regular")
-
 test_that("conversion produces right classes", {
   x0 <- AirPassengers
   x0[c(10, 15)] <- NA
@@ -34,11 +28,9 @@ test_that("handles, regular, non standard series correctly", {
 
 
 test_that("does not change colnames in non standard order", {
-
   x <- ts_df(ts_c(mdeaths, fdeaths))
   setcolorder(x, c("time", "id", "value"))
   expect_equal(ts_regular(x), x)
-
 })
 
 test_that("fill argument works", {
@@ -49,6 +41,3 @@ test_that("fill argument works", {
   expect_equal(z[[2]][2], -9999)
   expect_equal(ts_regular(x0, 0)[2], 0)
 })
-
-
-
